@@ -24,8 +24,6 @@
 #' @param params List of parameters; Add columns with information to returning data.frame
 #' @param verbose Logical; To show more information
 #' @param fortran Logical; to try the fortran calculation.
-#' @param nt Integer; Number of threads wich must be lower than max available. See \code{\link{check_nt}}.
-#' Only when fortran = TRUE
 #' @return Emissions data.frame
 #' @seealso \code{\link{ef_ldv_speed}} \code{\link{ef_china}}
 #' @export
@@ -189,8 +187,7 @@ emis_hot_td <- function (veh,
                          pro_month,
                          params,
                          verbose = FALSE,
-                         fortran = FALSE,
-                         nt = ifelse(check_nt()==1, 1, check_nt()/2)) {
+                         fortran = FALSE) {
   # Checking sf
   if(any(class(veh) %in% "sf")){
     if(verbose) message("converting sf to data.frame")
@@ -290,22 +287,6 @@ emis_hot_td <- function (veh,
           month <- as.matrix(pro_month)
           # emis(i, j, k) = veh(i, j) * lkm(j) * ef(i, j)*month(i, k)
 
-          if(!missing(nt)) {
-            if(nt >= check_nt()) stop("Your machine has ", check_nt(),
-                                      " threads and nt must be lower")
-            if(verbose) message("Calling emistd2fpar.f95")
-            a <-   .Fortran("emistd2fpar",
-                            nrowv = nrowv,
-                            ncolv = ncolv,
-                            pmonth = pmonth,
-                            veh = as.matrix(veh),
-                            lkm = lkm,
-                            ef = ef,
-                            month = month,
-                            emis = numeric(nrowv*ncolv*pmonth),
-                            nt = as.integer(nt))$emis
-
-          } else {
             if(verbose) message("Calling emistd2f.f95")
             a <-   .Fortran("emistd2f",
                             nrowv = nrowv,
@@ -317,8 +298,6 @@ emis_hot_td <- function (veh,
                             month = month,
                             emis = numeric(nrowv*ncolv*pmonth))$emis
 
-          }
-
           e <- data.frame(emissions = a)
           e <- Emissions(e)
           e$rows <- rep(row.names(veh), each = ncolv*pmonth) # i
@@ -359,22 +338,6 @@ emis_hot_td <- function (veh,
 
           # emis(i, j, k) = veh(i, j) * lkm(j) * ef(i, j)*month(k)
 
-          if(!missing(nt)) {
-            if(nt >= check_nt()) stop("Your machine has ", check_nt(),
-                                      " threads and nt must be lower")
-            if(verbose) message("Calling emistd1fpar.f95")
-            a <-   .Fortran("emistd1fpar",
-                            nrowv = nrowv,
-                            ncolv = ncolv,
-                            pmonth = pmonth,
-                            veh = as.matrix(veh),
-                            lkm = lkm,
-                            ef = ef,
-                            month = month,
-                            emis = numeric(nrowv*ncolv*pmonth),
-                            nt = as.integer(nt))$emis
-
-          } else {
             if(verbose) message("Calling emistd1f.f95")
             a <-   .Fortran("emistd1f",
                             nrowv = nrowv,
@@ -386,9 +349,6 @@ emis_hot_td <- function (veh,
                             month = month,
                             emis = numeric(nrowv*ncolv*pmonth))$emis
 
-          }
-
-
           e <- data.frame(emissions = a)
           e <- Emissions(e)
           e$rows <- rep(row.names(veh), ncolv*pmonth)            # i
@@ -479,23 +439,6 @@ emis_hot_td <- function (veh,
 
           # emis(i, j, k) = veh(i, j) * lkm(j) * ef(i, j, k) * month(i, k)
 
-          if(!missing(nt)) {
-            if(nt >= check_nt()) stop("Your machine has ", check_nt(),
-                                      " threads and nt must be lower")
-
-            if(verbose) message("Calling emistd4fpar.f95")
-            a <-   .Fortran("emistd4fpar",
-                            nrowv = nrowv,
-                            ncolv = ncolv,
-                            pmonth = pmonth,
-                            veh = as.matrix(veh),
-                            lkm = lkm,
-                            ef = ef2,
-                            month = month,
-                            emis = numeric(nrowv*ncolv*pmonth),
-                            nt = as.integer(nt))$emis
-          } else {
-
             if(verbose) message("Calling emistd4f.f95")
 
             a <-   .Fortran("emistd4f",
@@ -507,8 +450,6 @@ emis_hot_td <- function (veh,
                             ef = ef2,
                             month = month,
                             emis = numeric(nrowv*ncolv*pmonth))$emis
-          }
-
 
           e <- data.frame(emissions = a)
           e <- Emissions(e)
@@ -555,26 +496,6 @@ emis_hot_td <- function (veh,
           if(length(lkm) != ncol(veh)) stop("length of `lkm` must be equal to number of columns of `veh`")
           # emis(i, j, k) = veh(i, j) * lkm(j) * ef(i, j, k) * month(k)
 
-          if(!missing(nt)) {
-            if(nt >= check_nt()) stop("Your machine has ", check_nt(),
-                                      " threads and nt must be lower")
-
-
-            if(verbose) message("Calling emistd3fpar.f95")
-
-            a <-   .Fortran("emistd3fpar",
-                            nrowv = nrowv,
-                            ncolv = ncolv,
-                            pmonth = pmonth,
-                            veh = as.matrix(veh),
-                            lkm = lkm,
-                            ef = ef2,
-                            month = month,
-                            emis = numeric(nrowv*ncolv*pmonth),
-                            nt = as.integer(nt))$emis
-          } else {
-            if(verbose) message("Calling emistd3f.f95")
-
             a <-   .Fortran("emistd3f",
                             nrowv = nrowv,
                             ncolv = ncolv,
@@ -585,7 +506,6 @@ emis_hot_td <- function (veh,
                             month = month,
                             emis = numeric(nrowv*ncolv*pmonth))$emis
 
-          }
           e <- data.frame(emissions = a)
           e <- Emissions(e)
           e$rows <- rep(row.names(veh),  ncolv*pmonth)           # i
@@ -659,25 +579,7 @@ emis_hot_td <- function (veh,
 
           # emis(i, j, k) = veh(i,j) * lkm(j) * ef(j) * month(i, k)
 
-          if(!missing(nt)) {
-            if(nt >= check_nt()) stop("Your machine has ", check_nt(),
-                                      " threads and nt must be lower")
-
-            if(verbose) message("Calling emistd6fpar.f95")
-
-            a <-   .Fortran("emistd6fpar",
-                            nrowv = nrowv,
-                            ncolv = ncolv,
-                            pmonth = pmonth,
-                            veh = as.matrix(veh),
-                            lkm = lkm,
-                            ef = ef,
-                            month = month,
-                            emis = numeric(nrowv*ncolv*pmonth),
-                            nt = as.integer(nt))$emis
-
-          } else {
-            if(verbose) message("Calling emistd6f.f95")
+          if(verbose) message("Calling emistd6f.f95")
 
             a <-   .Fortran("emistd6f",
                             nrowv = nrowv,
@@ -689,8 +591,6 @@ emis_hot_td <- function (veh,
                             month = month,
                             emis = numeric(nrowv*ncolv*pmonth))$emis
 
-          }
-
           e <- data.frame(emissions = a)
           e <- Emissions(e)
           e$rows <- rep(row.names(veh), ncolv*pmonth)   # i
@@ -733,24 +633,6 @@ emis_hot_td <- function (veh,
           if(length(lkm) != ncol(veh)) stop("length of `lkm` must be equal to number of columns of `veh`")
           # emis(i, j, k) = veh(i, j) * lkm(j) * ef(j) * month(k)
 
-          if(!missing(nt)) {
-            if(nt >= check_nt()) stop("Your machine has ", check_nt(),
-                                      " threads and nt must be lower")
-
-            if(verbose) message("Calling emistd5fpar.f95")
-
-            a <-   .Fortran("emistd5fpar",
-                            nrowv = nrowv,
-                            ncolv = ncolv,
-                            pmonth = pmonth,
-                            veh = as.matrix(veh),
-                            lkm = lkm,
-                            ef = ef,
-                            month = month,
-                            emis = numeric(nrowv*ncolv*pmonth),
-                            nt = as.integer(nt))$emis
-
-          } else {
             if(verbose) message("Calling emistd5f.f95")
 
             a <-   .Fortran("emistd5f",
@@ -763,8 +645,6 @@ emis_hot_td <- function (veh,
                             month = month,
                             emis = numeric(nrowv*ncolv*pmonth))$emis
 
-          }
-
           e <- data.frame(emissions = a)
           e <- Emissions(e)
           e$rows <- rep(row.names(veh), ncolv*pmonth)
@@ -823,22 +703,6 @@ emis_hot_td <- function (veh,
         # emis(i, j) = veh(i,j) * lkm(j) * ef(j)
 
 
-        if(!missing(nt)) {
-          if(nt >= check_nt()) stop("Your machine has ", check_nt(),
-                                    " threads and nt must be lower")
-
-          if(verbose) message("Calling emistd7fpar.f95")
-
-          a <-   .Fortran("emistd7fpar",
-                          nrowv = nrowv,
-                          ncolv = ncolv,
-                          veh = as.matrix(veh),
-                          lkm = lkm,
-                          ef = ef,
-                          emis = numeric(nrowv*ncolv),
-                          nt = as.integer(nt))$emis
-
-        } else {
           if(verbose) message("Calling emistd7f.f95")
 
           a <-   .Fortran("emistd7f",
@@ -849,7 +713,6 @@ emis_hot_td <- function (veh,
                           ef = ef,
                           emis = numeric(nrowv*ncolv))$emis
 
-        }
         # fortran
         # do concurrent(i= 1:nrowv, j = 1:ncolv)
         # emis(i, j) = veh(i,j) * lkm(i) * ef(j)
