@@ -66,15 +66,11 @@ test_that("emis_cold works", {
                                   fortran = T,
                                   beta = cold_lkm,
                                   pro_month = veh_month,
-                                  verbose = T,
-                                  nt = 1)$emissions[1]),
+                                  verbose = T)$emissions[1]),
                30)
   expect_equal(round(emis_cold_td(veh = veh, lkm = lkm, ef = EmissionFactors(efhh), efcold = efc, fortran = T,
                                   beta = cold_lkm, pro_month = veh_month, verbose = T)$emissions[1]),
                30)
-  expect_error(emis_cold_td(veh = veh, lkm = lkm, ef = EmissionFactors(efhh), efcold = efc, fortran = T,
-                                  beta = cold_lkm, pro_month = veh_month, verbose = T, nt = 100),
-               ".?")
   expect_message(round(emis_cold_td(veh = veh, lkm = lkm, ef = efh, efcold = efc,
                                     beta = cold_lkm,
                                     pro_month = veh_month,
@@ -91,8 +87,13 @@ test_that("emis_cold works", {
                                    verbose = T)$emissions[1]),
                 "S.?")
   expect_equal(
-    round(emis_cold_td(veh = veh, lkm = lkm, ef = efh, efcold = efc,
-                       beta = cold_lkm, pro_month = veh_month, verbose = FALSE,
+    round(emis_cold_td(veh = veh,
+                       lkm = lkm,
+                       ef = efh,
+                       efcold = efc,
+                       beta = cold_lkm,
+                       pro_month = veh_month,
+                       verbose = FALSE,
                        params = list(paste0("data_", 1:10), "moredata"))$emissions[1]),
     7)
 })
@@ -139,9 +140,8 @@ test_that("emis_cold stops", {
                  params = list(paste0("data_", 1:10), "moredata")),
     ".?")
 })
-
-veh_month <- as.data.frame(matrix(veh_month, ncol = 12) )
-
+veh_month <- c(rep(8, 1), rep(10, 5), 9, rep(10, 5))
+df_month <- as.data.frame(matrix(veh_month, ncol = 12) )
 
 test_that("emis_cold works", {
   expect_equal(round(emis_cold_td(veh = veh,
@@ -149,7 +149,7 @@ test_that("emis_cold works", {
                                   ef = efh,
                                   efcold = efc,
                                   beta = cold_lkm,
-                                  pro_month = veh_month,
+                                  pro_month = df_month,
                                   verbose = T)$emissions[1]),
                7)
   expect_equal(round(emis_cold_td(veh = veh,
@@ -157,26 +157,16 @@ test_that("emis_cold works", {
                                   ef = EmissionFactors(as.numeric(efh[, 1:ncol(veh)])),
                                   efcold = efc,
                                   beta = cold_lkm,
-                                  pro_month = veh_month,
+                                  pro_month = df_month,
                                   verbose = T)$emissions[1]),
                7)
 
-  expect_error(round(emis_cold_td(veh = veh,
-                                  lkm = lkm,
-                                  ef = EmissionFactors(as.numeric(efh[, 1:ncol(veh)])),
-                                  efcold = efc,
-                                  beta = cold_lkm,
-                                  pro_month = veh_month,
-                                  verbose = T,
-                                  fortran = TRUE,
-                                  nt = 1000)$emissions[1]),
-               ".?")
   expect_equal(round(emis_cold_td(veh = veh,
                                   lkm = lkm,
                                   ef = EmissionFactors(as.numeric(efh[, 1:ncol(veh)])),
                                   efcold = efc,
                                   beta = cold_lkm,
-                                  pro_month = veh_month,
+                                  pro_month = df_month,
                                   verbose = T,
                                   fortran = TRUE)$emissions[1]),
                7)
@@ -186,10 +176,9 @@ test_that("emis_cold works", {
                                   ef = EmissionFactors(as.numeric(efh[, 1:ncol(veh)])),
                                   efcold = efc,
                                   beta = cold_lkm,
-                                  pro_month = veh_month,
+                                  pro_month = df_month,
                                   verbose = T,
-                                  fortran = TRUE,
-                                  nt = 1)$emissions[1]),
+                                  fortran = TRUE)$emissions[1]),
                7)
 
   expect_error(emis_cold_td(veh = veh,
@@ -198,7 +187,7 @@ test_that("emis_cold works", {
                             efcold = efc,
                             fortran = TRUE,
                             beta = cold_lkm,
-                            pro_month = veh_month,
+                            pro_month = df_month,
                             verbose = T),
                ".?")
 
@@ -210,7 +199,7 @@ test_that("emis_cold works", {
                                   ef = EmissionFactors(efhh),
                                   efcold = efc,
                                   beta = cold_lkm,
-                                  pro_month = veh_month,
+                                  pro_month = df_month,
                                   verbose = T)$emissions[1]),
                30)
   expect_equal(round(emis_cold_td(veh = veh,
@@ -219,19 +208,9 @@ test_that("emis_cold works", {
                                   efcold = efc,
                                   fortran = TRUE,
                                   beta = cold_lkm,
-                                  pro_month = veh_month,
+                                  pro_month = df_month,
                                   verbose = T)$emissions[1]),
                30)
-  expect_equal(round(emis_cold_td(veh = veh,
-                                  lkm = lkm,
-                                  ef = EmissionFactors(efhh),
-                                  efcold = efc,
-                                  fortran = TRUE,
-                                  beta = cold_lkm,
-                                  pro_month = veh_month,
-                                  verbose = T,
-                                  nt = 1)$emissions[1]),
-               30)
 })
 
 
@@ -241,14 +220,19 @@ test_that("emis_cold does not work", {
                                   ef = efh,
                                   efcold = remove_units(efc),
                                   beta = cold_lkm,
-                                  pro_month = veh_month,
+                                  pro_month = df_month,
                                   verbose = T)$emissions[1]),
                ".?")
 
   efhh <- as.data.frame(
     matrix(seq_along(veh), nrow =  nrow(veh), ncol = ncol(veh)))
-  expect_error(round(emis_cold_td(veh = veh, lkm = lkm, ef = EmissionFactors(efhh), efcold = remove_units(efc),
-                                  beta = cold_lkm, pro_month = veh_month, verbose = T)$emissions[1]),
+  expect_error(round(emis_cold_td(veh = veh,
+                                  lkm = lkm,
+                                  ef = EmissionFactors(efhh),
+                                  efcold = remove_units(efc),
+                                  beta = cold_lkm,
+                                  pro_month = df_month,
+                                  verbose = T)$emissions[1]),
                ".?")
 })
 
